@@ -16,6 +16,7 @@ class VCRHTTPResponse(object):
         self.status = recorded_response['status']['code']
         self.version = None
         self._content = StringIO(self.recorded_response['body']['string'])
+        self.closed = False
 
         # We are skipping the header parsing (they have already been parsed
         # at this point) and directly  adding the headers to the header
@@ -37,12 +38,13 @@ class VCRHTTPResponse(object):
         return self._content.read(*args, **kwargs)
 
     def close(self):
+        self.closed = True
         return True
 
     def isclosed(self):
         # Urllib3 seems to call this because it actually uses
         # the weird chunking support in httplib
-        return True
+        return self.closed
 
     def getheaders(self):
         return self.recorded_response['headers'].iteritems()
@@ -79,18 +81,18 @@ class VCRConnectionMixin:
 
     def close(self):
         self._restore_socket()
-	self._baseclass.close(self)
+        self._baseclass.close(self)
 
     def _restore_socket(self):
         """
-	Since some libraries (REQUESTS!!) decide to set options on
-	connection.socket, I need to delete the socket attribute
-	(which makes requests think this is a AppEngine connection)
-	and then restore it when I want to make the actual request.
-	This function restores it to its standard initial value
-	(which is None)
+        Since some libraries (REQUESTS!!) decide to set options on
+        connection.socket, I need to delete the socket attribute
+        (which makes requests think this is a AppEngine connection)
+        and then restore it when I want to make the actual request.
+        This function restores it to its standard initial value
+        (which is None)
         """
-	if not hasattr(self, 'sock'):
+        if not hasattr(self, 'sock'):
             self.sock = None
 
     def _send_request(self, method, url, body, headers):
@@ -148,7 +150,7 @@ class VCRConnectionMixin:
         if isinstance(message_body, str):
             msg += message_body
             message_body = None
-	self._restore_socket()
+        self._restore_socket()
         self._baseclass.send(self, msg)
         if message_body is not None:
             #message_body was not a string (i.e. it is a file) and
@@ -159,12 +161,8 @@ class VCRConnectionMixin:
         '''Retrieve a the response'''
         # Check to see if the cassette has a response for this request. If so,
         # then return it
-        if self._vcr_request in self.cassette and \
-                self.cassette.record_mode != "all":
+        if self._vcr_request in self.cassette and  self.cassette.record_mode != "all" and self.cassette.rewound:
             response = self.cassette.response_of(self._vcr_request)
-            # Alert the cassette to the fact that we've served another
-            # response for the provided requests
-            self.cassette.mark_played(self._vcr_request)
             return VCRHTTPResponse(response)
         else:
             if self.cassette.write_protected:
@@ -173,10 +171,10 @@ class VCRConnectionMixin:
             # Otherwise, we should send the request, then get the response
             # and return it.
 
-	    # restore sock's value to None, since we need a real socket
-	    self._restore_socket()
+           # restore sock's value to None, since we need a real socket
+            self._restore_socket()
 
-	    #make the actual request
+            #make the actual request
             self._baseclass.request(
                 self,
                 method=self._vcr_request.method,
@@ -209,8 +207,8 @@ class VCRHTTPConnection(VCRConnectionMixin, HTTPConnection):
 
     def __init__(self, *args, **kwargs):
         HTTPConnection.__init__(self, *args, **kwargs)
-	# see VCRConnectionMixin._restore_socket for the motivation here
-	del self.sock
+        # see VCRConnectionMixin._restore_socket for the motivation here
+        del self.sock
 
 
 class VCRHTTPSConnection(VCRConnectionMixin, HTTPSConnection):
@@ -225,5 +223,5 @@ class VCRHTTPSConnection(VCRConnectionMixin, HTTPSConnection):
         HTTPConnection.__init__(self, *args, **kwargs)
         self.key_file = kwargs.pop('key_file', None)
         self.cert_file = kwargs.pop('cert_file', None)
-	# see VCRConnectionMixin._restore_socket for the motivation here
-	del self.sock
+        # see VCRConnectionMixin._restore_socket for the motivation here
+        del self.sock
